@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.73';
+$App::pherkin::VERSION = '0.74';
 use strict;
 use warnings;
 
@@ -36,7 +36,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 SYNOPSIS
 
@@ -128,7 +128,7 @@ sub _run_tests {
     $harness->shutdown();
 
     my $exit_code = 0;
-    my $result = $harness->result;
+    my $result = $harness->result->result;
     if ($result eq 'failing') {
         $exit_code = 2;
     }
