@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::I18N::Data;
-$Test::BDD::Cucumber::I18N::Data::VERSION = '0.73';
+$Test::BDD::Cucumber::I18N::Data::VERSION = '0.74';
 use strict;
 use warnings;
 use utf8;
@@ -14,7 +14,7 @@ Test::BDD::Cucumber::I18N::Data - Cucumber language definitions
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 DESCRIPTION
 
@@ -3195,7 +3195,7 @@ __DATA__
       "เมื่อ "
     ]
   },
-  "tl": {
+  "te": {
     "and": [
       "* ",
       "మరియు "
